export interface Unit {
    name: {
        singular: string;
        plural: string;
    };
    to_anchor: number;
    anchor_shift?: number;
}
export interface Conversion<TMeasures extends string, TSystems extends string, TUnits extends string> {
    abbr: TUnits;
    measure: TMeasures;
    system: TSystems;
    unit: Unit;
}
export interface UnitDescription {
    abbr: string;
    measure: string;
    system: string;
    singular: string;
    plural: string;
}
type TransformFunc = (value: number) => number;
export interface Anchor {
    ratio?: number;
    transform?: TransformFunc;
}
export interface Measure<TSystems extends string, TUnits extends string> {
    systems: Partial<Record<TSystems, Partial<Record<TUnits, Unit>>>>;
    anchors?: Partial<Record<TSystems, Partial<Record<TSystems, Anchor>>>>;
}
export interface BestResult {
    val: number;
    unit: string;
    singular: string;
    plural: string;
}
/**
 * Represents a conversion path
 */
export declare class Converter<TMeasures extends string, TSystems extends string, TUnits extends string> {
    private val;
    private destination;
    private origin;
    private measureData;
    constructor(measures: Record<TMeasures, Measure<TSystems, TUnits>>, value?: number);
    /**
     * Lets the converter know the source unit abbreviation
     */
    from(from: TUnits): this;
    /**
     * Converts the unit and returns the value
     */
    to(to: TUnits): number;
    /**
     * Converts the unit to the best available unit.
     */
    toBest(options?: {
        exclude?: TUnits[];
        cutOffNumber?: number;
        system?: TSystems;
    }): BestResult | null;
    /**
     * Finds the unit
     */
    getUnit(abbr: TUnits): Conversion<TMeasures, TSystems, TUnits> | null;
    /**
     * An alias for getUnit
     */
    describe(abbr: TUnits): UnitDescription | never;
    private describeUnit;
    /**
     * Detailed list of all supported units
     *
     * If a measure is supplied the list will only contain
     * details about that measure. Otherwise the list will contain
     * details abaout all measures.
     *
     * However, if the measure doesn't exist, an empty array will be
     * returned
     *
     */
    list(measureName?: TMeasures): UnitDescription[] | never;
    private throwUnsupportedUnitError;
    /**
     * Returns the abbreviated measures that the value can be
     * converted to.
     */
    possibilities(forMeasure?: TMeasures): TUnits[];
    /**
     * Returns the abbreviated measures that the value can be
     * converted to.
     */
    measures(): TMeasures[];
}
export default function <TMeasures extends string, TSystems extends string, TUnits extends string>(measures: Record<TMeasures, Measure<TSystems, TUnits>>): (value?: number) => Converter<TMeasures, TSystems, TUnits>;
export {};
//# sourceMappingURL=convert.d.ts.map